@@ -29,20 +29,22 @@ class RedisClusterCache(RedisCache):
         skip_full_coverage_check: bool = False,
         reinitialize_steps: int = 10,
         read_from_replicas: bool = False,
+        url: Any = None,
         namespace: str = DEFAULT_NAMESPACE,
         key_prefix: str = DEFAULT_PREFIX,
         key_builder: Callable[..., Any] = key_builder,
         **kwargs,
     ) -> None:
         self.redis = RedisCluster(
-            host,
-            port,
-            startup_nodes,
-            cluster_error_retry_attempts,
-            require_full_coverage,
-            skip_full_coverage_check,
-            reinitialize_steps,
-            read_from_replicas,
+            host=host,
+            port=port,
+            startup_nodes=startup_nodes,
+            cluster_error_retry_attempts=cluster_error_retry_attempts,
+            require_full_coverage=require_full_coverage,
+            skip_full_coverage_check=skip_full_coverage_check,
+            reinitialize_steps=reinitialize_steps,
+            read_from_replicas=read_from_replicas,
+            url=url,
             **kwargs,
         )
         self.encoder = encoder
@@ -66,6 +68,7 @@ class RedisClusterCache(RedisCache):
         skip_full_coverage_check: bool = False,
         reinitialize_steps: int = 10,
         read_from_replicas: bool = False,
+        url: Any = None,
         namespace: str = DEFAULT_NAMESPACE,
         key_prefix: str = DEFAULT_PREFIX,
         key_builder: Callable[..., Any] = key_builder,
@@ -81,6 +84,7 @@ class RedisClusterCache(RedisCache):
                 skip_full_coverage_check=skip_full_coverage_check,
                 reinitialize_steps=reinitialize_steps,
                 read_from_replicas=read_from_replicas,
+                url=url,
                 encoder=encoder,
                 decoder=decoder,
                 namespace=namespace,
